@@ -1,5 +1,4 @@
 import copy
-import itertools
 import math
 import os
 import re
@@ -807,22 +806,18 @@ class Font:
 
         def get_euclidean_distance(a, b):
             # https://en.wikipedia.org/wiki/Euclidean_distance#Higher_dimensions
+            keys = set(list(a.keys()) + list(b.keys()))
             return math.sqrt(
-                sum(
-                    map(
-                        lambda ab: math.pow(abs(ab[0] - ab[1]), 2),
-                        list(itertools.zip_longest(a, b, fillvalue=0)),
-                    )
-                )
+                sum([math.pow(a.get(key, 0) - b.get(key, 0), 2) for key in keys])
             )
 
-        lookup_values = coordinates.values()
+        lookup_values = coordinates
         instances = self.get_variable_instances()
         closest_instance_distance = sys.maxsize
         closest_instance = None
         for instance in instances:
-            instance_values = instance["coordinates"].values()
-            instance_distance = get_euclidean_distance(lookup_values, instance_values)
+            instance_values = instance["coordinates"]
+            instance_distance = get_euclidean_distance(instance_values, lookup_values)
             if instance_distance < closest_instance_distance:
                 closest_instance_distance = instance_distance
                 closest_instance = instance
@@ -936,24 +931,19 @@ class Font:
         wws_family_name = family_name
         wws_subfamily_name = style_name
 
-        # family name, subfamily name and full name
-        family_name_parts = [family_name]
-        style_name_parts = style_name.split()
-        subfamily_name_parts = style_name.lower().split()
+        # family name, subfamily name and full name - fix legacy name records 1 and 2
         subfamily_names = ["regular", "italic", "bold", "bold italic"]
-        subfamily_name_default = subfamily_names[0]
-        for name_part in style_name_parts:
-            if name_part.lower() not in subfamily_names:
-                family_name_parts.append(name_part)
-                subfamily_name_parts.remove(name_part.lower())
-        if subfamily_name_default in subfamily_name_parts:
-            if len(subfamily_name_parts) > 1:
-                subfamily_name_parts.remove(subfamily_name_default)
-        subfamily_name_parts = subfamily_name_parts or [subfamily_name_default]
-        family_name = " ".join(family_name_parts)
-        subfamily_name = " ".join(subfamily_name_parts).lower()
-        if subfamily_name not in subfamily_names:
-            subfamily_name = subfamily_name_default
+        subfamily_name = style_name
+        style_name_lower = style_name.lower()
+        if style_name_lower not in subfamily_names:
+            subfamily_name = (
+                "Italic" if style_name_lower.endswith(" italic") else "Regular"
+            )
+            family_name_suffix = re.sub(
+                r"\ italic$", "", subfamily_name, flags=re.IGNORECASE
+            )
+            assert family_name_suffix
+            family_name = f"{typographic_family_name} {family_name_suffix}"
 
         subfamily_name = subfamily_name.title()
 
@@ -1242,10 +1232,8 @@ class Font:
         :rtype: bool
         """
         return all(
-            [
-                isinstance(axis_value, (type(None), int, float))
-                for axis_value in axes.values()
-            ]
+            isinstance(axis_value, (type(None), int, float))
+            for axis_value in axes.values()
         )
 
     def to_sliced_variable(self, coordinates, **options):
